<?php

/**
 * @file
 * Contains \Drupal\ces\Plugin\CsvParser\Users.
 *
 */
namespace Drupal\ces\Plugin\CsvParser;

use Drupal\user\UserInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;


/**
 * Plugin to import users
 *
 * @Plugin(
 *   id = "members",
 *   label = "Users"
 * )
 */
class Users extends \Drupal\cforge_import\Plugin\CsvParser\Users implements ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public static function columns() {
    return parent::columns() + [
      'privacy_phone1' => t('boolean flag for privacy of first phone number'),
      'privacy_phone2' => t('boolean flag for privacy of second phone number'),
      'privacy_address' => t('boolean flag for privacy of first line of address'),
    ];
  }

  //batch callback.
  //the sandbox seems to be empty every time, unfortunately
  static function saveEntities($rows, $test, &$sandbox) {
    parent::saveEntities($rows, $test, $sandbox);
    foreach ($rows as $rownum => $row) {
      $val = [
        'phone1' => $row['privacy_phone1'],
        'phone2' => $row['privacy_phone2'],
        'address' => $row['privacy_address']
      ];
      $user_ids = \Drupal::entityTypeManager()
        ->getStorage('user')->getQuery()
        ->condition('name', $row['name'])
        ->execute();
      \Drupal::keyValue('user.privacy')->set(reset($user_ids), $val);
    }
  }

  //not sure what the status of this is
  static function coordinatorProcess(UserInterface $account, $val, &$allfields) {
    //$account->addRole('superneighbour');
  }

  /**
   *
   * //ind|fam|com|org|pub|adm
   */
  static function roleProcess(UserInterface $account, $val, &$allfields) {
    if (strlen($allfields['firstname']) > 25 or strlen($allfields['lastname']) > 25) {
      $val = 'org';
      $allfields['address.organization'] = $allfields['firstname'].$allfields['lastname'];
      $allfields['firstname'] = substr($allfields['firstname'], 0, 25);
      $allfields['lastname'] = substr($allfields['lastname'], 0, 25);
    }
    $account->addRole('trader');
    switch($val) {
      case 'ind':
      case 'fam':
      case 'com':
      case 'org':
        $account->walletType = $val;
        break;
      case 'pub'://publicly visible wallet permission
        drupal_set_message('public/private wallet setting not yet supported');
        break;
      case 'adm':
        $account->addRole('committee');
        break;
      default:
        throw new Exception('Unknown role: '.$val);
    }
  }

  static function privacy_phone1Process() {}
  static function privacy_phone2Process() {}
  static function privacy_addressProcess() {}


}
