<?php

/**
 * @file
 * Contains \Drupal\ces\TransactionSubscriber.
 */

namespace Drupal\ces;

use Drupal\mcapi\McapiEvents;
use Drupal\mcapi\Event\TransactionAssembleEvent;
use Drupal\Component\EventDispatcher\ContainerAwareEventDispatcher;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 *
 */
class TransactionSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      McapiEvents::ASSEMBLE => ['onmakeChildren']
      //,McapiEvents::ACTION => ['onTransactionAction']
    ];
  }

  /**
   *
   * This is an example for now, but it mightMcapi work with rules later on.
   * use $event->addChild($transaction)
   *
   * @param TransactionAssembleEvent $event
   *   no ->arguments() are passed. getSubject() returns the transaction
   * @param string $eventName which is always mcapi_transaction.assemble
   * @param ContainerAwareEventDispatcher $container
   */
  function onMakeChildren(TransactionAssembleEvent $event) {
    $transaction = $event->getSubject();
    $fees = \Drupal::config('mcapi.fees');
    if (!$fees->get('rate')) {
      return;
    }
    if ($transaction->type->target_id != 'default') {
      return;
    }
    if ($fees->get('payer')) {
      $payers[] = $transaction->payer->target_id;
    }
    if ($fees->get('payee')) {
      $payers[] = $transaction->payee->target_id;
    }
    
    $current_value = $transaction->worth->{$fees->get('curr_id')};
    $temp =  $current_value * $fees->get('rate');
    $levy_value = $fees->get('round_up') ? ceil($temp/100) : floor($temp/100);
      
    foreach ($payers as $payer) {
      $props = [
        'creator' => 1,//user id
        'type' => 'auto',//references \Drupal\mcapi\Entity\Type
        'worth' => [
          0 => [
            'curr_id' => $fees->get('curr_id'),
            'value' => $levy_value
          ]
        ],
        'payer' => $payer,
        'payee' => $fees->get('target'),
        'description' => 'temp',//$fees->get('description')
      ];
      $child = \Drupal\mcapi\Entity\Transaction::create($props + ['payer' => $transaction->payer->target_id]);
      $event->addChild($child);
    }
    
  }

  /**
   * Does things with a transactions and returns a render array in $events->output
   *
   * @param TransactionSaveEvents $events
   *   $events->getArguments() yields form_values, old_state and operation name, or action
   *   $events->getSubject() gives the transaction
   * @param string $eventName
   * @param ContainerAwareEventDispatcher $container
   */
  function onTransactionAction(TransactionSaveEvents $events, $eventName, ContainerAwareEventDispatcher $container) {
    $events->addMessage('onTransactionAction: '.$eventName);
  }

}
