<?php

/**
 * @file
 * Contains \Drupal\cforge_import\ImportBase.
 *
 */
namespace Drupal\cforge_import\Plugin\CsvParser;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Plugin\PluginBase;

abstract class ImportBase extends PluginBase implements CsvParserInterface {

  static function buildEntity(array $fields) {
    $entity = static::createEntity();
    foreach ($fields as $fieldname => $value) {
      $error = '';
      $class = get_called_class();
      if (strpos($fieldname, '.')) {
        list($field, $col) = explode('.', $fieldname);
        $method = $field.'_'.$col.'Process';
        if (method_exists($class, $method)) {
          $error = $class::{$method}($entity, $fields[$fieldname], $fields);
        }
        elseif ($value) {
          $entity->{$field}->{$col} = $value;
        }
      }
      elseif(in_array($fieldname, ['created', 'changed', 'access', 'expires'])) {
        $class::timeProcess($entity, $fieldname, $fields[$fieldname]);
      }
      else {
        $method = $fieldname.'Process';
        if (method_exists($class, $method)) {
          $error = $class::$method($entity, $fields[$fieldname], $fields);
        }
        else {
          $entity->set($fieldname, $value);
        }
      }
      if ($error) {
        drupal_set_message($error, 'warning');
      }
    }
    return $entity;
  }

  //batch callback.
  //the sandbox seems to be empty every time, unfortunately
  static function saveEntities($rows, $test, &$sandbox) {
    foreach ($rows as $rownum => $row) {
      $entity = static::buildEntity($row);
      foreach ($entity->validate() as $violation) {
        //N.B this doesn't prevent the entity from being saved.
        //actually maybe it does
        drupal_set_message($violation->getMessage() .' at '.$violation->getPropertyPath().' on row '.$rownum .': '.implode(' | ', $row));
      }
      if (!$test) {
        $result = $entity->save();
        drupal_set_message($entity->id().':'.$result);
      }
    }
  }

  static function timeProcess(EntityInterface $account, $fieldname, $val) {
    if ($val) {
      if (!is_integer($val)) {
        $val = strtotime($val);
      }
      $account->set($fieldname, $val);
    }
  }

  static function langcodeProcess(EntityInterface $account, $val, $allfields) {
    $account->set('langcode', $val);
    $account->set('preferred_langcode', $val);
  }

  static function ready() {
    return TRUE;
  }

  function makeBatch($rows, $delete = FALSE, $test = TRUE) {
    $batch = ['title' => 'Creating entities'];//this could be overwritten
    if ($delete) {
      $batch['operations'][] = [[$this, 'deleteAll'], []];
    }
    foreach (array_chunk($rows, 50) as $chunk) {
      $batch['operations'][] = [[$this, 'saveEntities'], [$chunk, $test]];
    }
    return $batch;
  }

  /**
   *
   * @throws \Exception
   */
  static function required($value, $default = NULL) {
    if ($value) {
      return $value;
    }
    if ($default) {
      return $default;
    }
    throw new \Exception('null required value');
  }


  function getCsvRows($data) {
    $csv = array_map('str_getcsv', explode(PHP_EOL, trim($data)));
    array_walk($csv, function(&$a) use ($csv) {
      $a = array_combine($csv[0], $a);
    });
    array_shift($csv); #remove first row
    $output = [];
    foreach ($csv as $key => $row) {
      foreach ($this->columns() as $col_name => $description) {
        if (isset($row[$col_name])) {
          $output[$key][$col_name] = $row[$col_name];
        }
      }
    }
    return $output;
  }

}
