<?php

/**
 * @file
 * Contains \Drupal\cforge_import\Plugin\CsvParser\Smallads.
 *
 */
namespace Drupal\cforge_import\Plugin\CsvParser;

use Drupal\smallads\Entity\SmallAdInterface;

abstract class Smallads extends ImportBase {

  /**
   * {@inheritdoc}
   */
  public static function deleteAll() {
    $entities = \Drupal::entityTypeManager()
      ->getStorage('smallad')
      ->loadByProperties(['type' => static::BUNDLE]);
    foreach ($entities as $entity) {
      $entity->delete();
    }
  }


  /**
   * {@inheritdoc}
   */
  public static function ready() {
    //can only import if there is more than one user
    return \Drupal::entityQuery('user')->count()->execute() > 1;
  }

  /**
   * {@inheritdoc}
   */
  static function createEntity() {
    return \Drupal::entityTypeManager()
      ->getStorage('smallad')
      ->create(['type' => static::BUNDLE]);
  }

  /**
   * {@inheritdoc}
   */
  public static function columns() {
    return [
      'name' => t('unique login name of owner user'),
      'title' => t('title of ad'),
      'body' => t('body of ad, in html'),
      'created' => t('item created date, format:  "2016-01-15 19:10:33'),
      'changed' => t('last changed date, format:  "2016-01-15 19:10:33"'),
      'scope' => t('0 means just the owner, 2 means every authenticated user can see it'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  function makeBatch($rows, $delete = FALSE, $test = TRUE) {
    $batch = parent::makeBatch($rows, $delete, $test);
    $batch['title'] = 'Importing '.$this->getPluginDefinition()['label'];
    return $batch;
  }


  static function bodyProcess(SmallAdInterface $entity, $val, $allfields) {
    $entity->body->value = $val;
    $entity->body->format = 'basic';
  }

  static function uidProcess(SmallAdInterface $entity, $val, $allfields) {
    $entity->setOwnerId($val);
  }

  static function categoriesProcess(SmallAdInterface $entity, $val, $allfields) {
    $vals = explode(',', $val);
    $existing_terms = \Drupal::entityTypeManager()
      ->getStorage('taxonomy_term')
      ->loadByProperties(['name' => $vals, 'vid' => SMALLAD_CATEGORIES]);
    //key the existing terms by name so we can look them up
    foreach ($existing_terms as $term) {
      $terms[$term->label()] = $term;
    }

    $categories = $entity->categories->getValue();
    foreach ($vals as $term_name) {
      $term_name = trim($term_name);
      if (!isset($terms[$term_name])) {
        $term = \Drupal\taxonomy\Entity\Term::Create(['name' => $term_name, 'vid' => SMALLAD_CATEGORIES]);
        $term->save();
        drupal_set_message('Created new term ' .$term_name);
        $terms[$term_name] = $term;
      }
      $categories[]['target_id'] = $terms[$term_name]->id();
    }
    $entity->categories->setvalue($categories);

  }

  static function pictureProcess(SmallAdInterface $entity, $val, $allfields) {
    if ($val) {
      //\Drupal::logger('ces')->debug($val);//this was causing an overload
      $info = pathinfo($val);
      $newpath = 'public://'.$info['basename'];
      if (copy($val, $newpath)) {
        $file = \Drupal\file\Entity\File::create(['uri' => $newpath]);
        $file->save();
        $entity->set('image', $file);
      }
    }
  }

  static function nameProcess(SmallAdInterface $entity, $val, $allfields) {
    $uids = \Drupal::entityQuery('user')->condition('name', $val)->execute();
    if (!$uids){
      drupal_set_message('User not identified for name '.$val);
      return;
    }
    $entity->setOwnerId(reset($uids));
  }

}
