<?php

/**
 * @file
 * Contains \Drupal\cforge_import\Plugin\CsvParser\Transactions.
 *
 */
namespace Drupal\cforge_import\Plugin\CsvParser;
use Drupal\mcapi\Entity\TransactionInterface;

abstract class Transactions extends ImportBase {

  private $allWallets = [];

  public static function columns() {
    return [
      'serial' => t('numeric identifer, not database key'),
      'payer' => t('integer wallet id e.g. abcd1234'),
      'payee' => t('integer wallet id e.g. abcd1234'),
      'quantity' => t('integer value of transaction'),
      'created' => t('Item created date in any strtotime format'),
      'state' => t('is always 1 which translates to TRANSACTION_STATE_DONE in D8'),
      'type' => t('string transaction type. name of Type plugin e.g. default'),
      'description' => t('plain text'),
    ];
  }

  public static function deleteAll() {
    foreach (\Drupal::entityTypeManager()->getStorage('mcapi_transaction')->loadMultiple() as $entity) {
      $entity->delete();
    }
  }

  /**
   * @todo support other states
   */
  protected static function stateProcess(TransactionInterface $entity, $val, $allfields) {
    if (is_numeric($val)) {
      switch($val) {
        case 1: $state = TRANSACTION_STATE_FINISHED; break;
        case 0: $state = TRANSACTION_STATE_ERASED; break;
        case -1: $state = TRANSACTION_STATE_PENDING; break;
        default:
          throw new \Exception('Unknown transaction state: '.$val);
      }
    }
    elseif (is_string($val)) {
      $state = $val;
    }
    $entity->state->target_id  = TRANSACTION_STATE_FINISHED;
  }

  protected static function typeProcess(TransactionInterface $entity, $val, $allfields) {
    switch($val) {
      case '3rdparty':
        break;
      case 'auto':
      case 'remote':
        break;
      case '1stparty':
      case 'default':
      default:
        $type = 'default';
    }
    $entity->type->target_id  = strtolower($type);
  }

  protected static function quantityProcess(TransactionInterface $entity, $val, $allfields) {
    $currency = \Drupal\mcapi\Entity\Currency::load('cc');
    @list($talents, $cents) = explode('.', $val);
    $entity->worth->curr_id = 'cc';
    $entity->worth->value = $currency->unformat([1 => $talents, 3 => $cents]);
  }


 /**
  * batch callback
  * @param type $rows
  * @param type $context
  */
  static function saveEntities($rows, $test, &$sandbox) {
    foreach ($rows as $rownum => $row) {
      $entity = static::buildEntity($row);
      foreach ($entity->validate() as $violation) {
        drupal_set_message($violation->getMessage());
      }
      if (!$test) {
        $class = get_called_class();
        $entity = $class::buildEntity($row);
        Self::stash($entity, $sandbox);
      }
    }
  }

  //we stash transactions with the tempStore so that we can group them by serial number before saving them all together
  static function stash($transaction, &$sandbox) {
    $tempstore = \Drupal::service('user.private_tempstore')->get('saved');
    //get the previous transaction if there is one, save it, and put the current transaction in the tempstore
    $previous_transaction = $tempstore->get('stash');
    if ($previous_transaction instanceOf \Drupal\mcapi\Entity\Transaction) {
      if ($transaction->type->target_id == 'default') {
        $previous_transaction->save();
        $tempstore->set('stash', $transaction);
      }
      elseif ($transaction->type->target_id == 'auto') {
        $prev->children[] = $transaction;
        $tempstore->set('stash', $prev);
      }
    }
    //first time we come here, just put the current transaction in the tempstore
    elseif($transaction->type->target_id != 'auto') {
      $tempstore->set('stash', $transaction);
    }
    else {
      mdump($transaction);
    }
  }

  static function saveLastTransaction($success, $results, $operations) {
    //trigger saving the last transaction
    //ugly workaround because the sandbox appears not to be working
    $last = \Drupal::service('user.private_tempstore')->get('saved')->get('stash');
    if ($last instanceof \Drupal\mcapi\Entity\Transaction) {
      $last->save();
    }
    else {
      drupal_set_message('problem saving last transaction: '.getType($last));
    }
    \Drupal::service('user.private_tempstore')->get('saved')->delete('stash');
  }

  function makeBatch($rows, $delete = FALSE, $test = TRUE) {
    //@todo this should really be injected
    \Drupal::service('user.private_tempstore')->get('saved')->delete('stash');
    $batch = parent::makeBatch($rows, $delete, $test);
    $batch['title'] = 'Importing transaction history';
    if (!$test) {
      $batch['finished'] = [$this, 'saveLastTransaction'];
    }
    return $batch;
  }

  static function createEntity() {
    return \Drupal::entityTypeManager()
      ->getStorage('mcapi_transaction')
      ->create(['type' => 'default']);
  }

}
