<?php

/**
 * @file
 * Definition of Drupal\digest\Digest.
 *
 */
namespace Drupal\digest;

class Digest {

  static function userSettingsForm($user) {
    //retrieve the settings form the user store
    $settings = \Drupal::service('user.data')->get('digest', $user->id(), 'digest') or
    $settings = [
      'displays' => [],
      'daysoftheweek' => [],
      'weeks_interval' => 1
    ];
    $form['displays'] = [
      '#type' => 'table',
      '#header' => [t('Views display'), t('Weight'), t('Enabled')],
      '#tabledrag' => [
        [
          'action' => 'order',
          'relationship' => 'sibling',
          'group' => 'weight',
        ]
      ]
    ];
    $delta = 15;
    $available_displays = array_keys(\Drupal::config('digest.settings')->get('views'));
    $selected_displays = SELF::getDisplays($settings['displays']);
    foreach ($available_displays as $display_id) {
    drupal_set_message($display_id);

      list($view_name, $display_name) = explode(':', $display_id);
      $title = \Drupal\views\Entity\View::load($view_name)->getDisplay($display_name)['display_title'];
      $weight = isset($settings['displays'][$display_id]) ? $settings['displays'][$display_id] : 0;

      $form['displays'][$display_id] = [
        'label' => ['#markup' => $title],
        'weight' => [
          '#title' => t('Weight for @title', ['@title' => $title]),
          '#title_display' => 'invisible',
          '#type' => 'weight',
          '#title_display' => 'invisible',
          '#delta' => max($delta, abs($weight)),
          '#default_value' => $weight,
          '#attributes' => ['class' => ['weight']]
        ],
        'enabled' => [
          '#type' => 'checkbox',
          '#default_value' => in_array($display_id, $selected_displays),
          '#attributes' => ['class' => ['weight']],
        ],
        '#weight' => $weight,
        '#attributes' => ['class' => ['draggable']],
      ];
    }
    uasort($form['displays'], array('\Drupal\Component\Utility\SortArray', 'sortByWeightProperty'));

    //this is a way to get the weekdays translated by php
    //Hat-tip to Carlos http://stackoverflow.com/users/462084/carlos
    $day_start = date( "d", strtotime( "next Sunday" ) ); // get next Sunday
    for ($x = 0; $x < 7; $x++) {
      $unixtime = mktime( 0, 0, 0, date( "m" ), $day_start + $x, date( "y" ));
      $week_days[date('w', $unixtime)] = date( 'l', $unixtime ); // create weekdays array.
    }
    $form['when'] = [
      '#type' => 'details',
      '#title' => t('When to send'),
      'daysoftheweek' => [
        '#title' => t('Days of the week'),
        '#type' => 'checkboxes',
        '#options' => $week_days,
        '#default_value' => $settings['daysoftheweek'],
        '#weight' => 5
      ],
      'weeks_interval' => [
        '#title' => t('Weeks interval'),
        '#type' => 'select',
        '#options' => [
          1 => t('Every week'),
          2 => t('Every 2 weeks'),
          4 => t('Every month'),
          8 => t('Every 2 months'),
          13 => t('Every 3 months'),
        ],
        '#default_value' => $settings['weeks_interval'],
        '#weight' => 7
      ]
    ];
    return $form;
  }


  static function userSettingsFormSubmit($form, $form_state, $user) {
    $displays = [];
    foreach ($form_state->getValue('displays') as $display_id => $props) {
      if (!$props['enabled']) {
        continue;
      }
      $displays[$display_id] = $props['weight'];
    }

    \Drupal::service('user.data')->set(
      'digest',
      $user->id(),
      'digest',
      [
        'displays' => $displays,
        'daysoftheweek' => $form_state->getValue('daysoftheweek'),
        'weeks_interval' => $form_state->getValue('weeks_interval')
      ]
    );
  }

  //adjust the displays so that if none are saved, all are returned
  static function getDisplays($saved_displays) {
    if (empty($saved_displays)) {
      $displays = \Drupal::config('digest.settings')->get('views');
    }
    else {
      $displays = array_keys($saved_displays);
    }
    return $displays;
  }

}
