<?php

/**
 * @file
 * Contains \Drupal\digest\SiteSettings.
 */

namespace Drupal\digest;

use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a user password reset form.
 */
class SiteSettings extends \Drupal\Core\Form\ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'digest_site_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $checkboxes = [];
    foreach (\Drupal\views\Views::getViewsAsOptions(FALSE, 'enabled') as $key => &$view_display) {
      list($view_id, $display_id) = explode(':', $key);
      $display = \Drupal::service('entity.manager')->getStorage('view')->load($view_id)->getDisplay($display_id);
      if ($display['display_plugin'] != 'embed') {
        continue;
      }
        $view = \Drupal\views\Entity\View::load($view_id);

      $options[$key] = $view->label() . ': '.$display['display_title'];
      $checkboxes[$key]['#disabled'] = TRUE;
      if (isset($display['display_options']['arguments'])) {

        $arguments = $display['display_options']['arguments'];

        if (reset($arguments)['plugin_id'] == 'date') {
          $checkboxes[$key]['#disabled'] = FALSE;
        }
      }
    }

    if (\Drupal::moduleHandler()->moduleExists('views_ui')) {
      $view_display_name = 'blah';
      foreach ($options as $key => $view_display) {
        list($view_id, $display_id) = explode(':', $key);
        $view_display_name = substr($view_display, 6);
        $options[$key] = \Drupal\Core\Link::createFromRoute(
          $view_display,
          'entity.view.edit_display_form',
          ['view' => $view_id, 'display_id' => $display_id],
          $options//todo open in a new window
        )->toString();
      }
    }
    $form['views'] = [
      '#title' => $this->t('Views displays suitable for digest.'),
      '#description' => $this->t("Only embed displays with a 'date' first argument are selectable. Argument is sometimes called 'Authored on'."),
      '#type' => 'checkboxes',
      '#options' => $options,
      '#default_value' => $this->config('digest.settings')->get('views')
    ]+$checkboxes;

    //@todo both of these are working at the moment
    $form['ui'] = [
      '#title' => $this->t('User interface'),
      '#type' => 'radios',
      '#options' => [
        'extra' => $this->t('Show settings as an extra field on the entity form display'),
        'tab' => $this->t('Show settings tab on the user profile')
      ],
      '#default_value' => $this->config('digest.settings')->get('ui')
    ];
    $form['actions'] = [
      '#type' => 'actions',
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Submit')
      ]
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->config('digest.settings')
        ->set('views', array_filter($values['views']))
        ->set('ui', $values['ui'])
        ->save();
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['digest.settings'];
  }

}
