<?php

/**
 * @file
 * Contains \Drupal\hamlets\Plugin\Block\CurrentUser
 */

namespace Drupal\hamlets\Plugin\Block;


use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Provides a chit for the current user
 *
 * @Block(
 *   id = "hamlets_current_user",
 *   admin_label = @Translation("Current user chit"),
 *   category = @Translation("Hamlets")
 * )
 */
class CurrentUser extends BlockBase implements ContainerFactoryPluginInterface {
  
  private $currentUser;
  private $userViewBuilder;
  
 /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_user'),
      $container->get('entity_type.manager')
    );
  }
  
  public function __construct(array $configuration, $plugin_id, $plugin_definition, $current_user, $entity_type_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentUser = $current_user;
    $this->userViewBuilder = $entity_type_manager->getViewBuilder('user');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $account = \Drupal\user\Entity\User::load($this->currentUser->id());
    //make a renderable array with user portrait image, user name & logout link
    $settings = [
      'type' => 'image', 
      'label' => 'hidden',
      'settings' => ['image_style' => 'thumbnail', 'image_link' => 'none']
    ];
    $portrait = $account->portrait->view($settings);print_r($portrait);
    
    return [
      [
        '#type' => 'link',
        '#title' => render($portrait), 
        '#url' => $account->toUrl('canonical'),
        '#attributes' => ['class' => ['portrait']],
        '#options' => ['html' => TRUE]
      ],
      [
        '#type' => 'link',
        '#title' => $account->label(), 
        '#url' => $account->toUrl('canonical'),
        '#attributes' => ['class' => ['userlink']]
      ],
      [
        '#type' => 'link',
        '#title' => $this->t('Logout'), 
        '#url' => \Drupal\Core\Url::fromRoute('user.logout'),
        '#attributes' => ['class' => ['logoutlink']]
      ]
    ];
  }
  
  
  public function __blockAccess(AccountInterface $account){
    return $account->id() ? AccessResult::allowed()->cachePerUser() : AccessResult::forbidden()->cachePerUser();
  }
  
}
