<?php

/**
 * @file
 * Contains \Drupal\hamlets\Plugin\CsvParser\Transactions.
 *
 */
namespace Drupal\hamlets\Plugin\CsvParser;
use Drupal\mcapi\Entity\TransactionInterface;


/**
 * Plugin to import transactions
 *
 * @Plugin(
 *   id = "transactions",
 *   label = @Translation("Transactions")
 * )
 */
class Transactions extends \Drupal\cforge_import\Plugin\CsvParser\Transactions {

  protected $entityTypeId = 'mcapi_transaction';
  protected $bundle = 'mcapi_transaction';

  private $allWallets = [];

  public static function columns() {
    $cols = parent::columns();
    $cols['payer'] = t('The email of the payer user');
    $cols['payee'] = t('The email of the payee user');
    $cols['categories'] = t('comma separated category names');
    return $cols;
  }


  protected function payerProcess(TransactionInterface $entity, $mail, $allfields) {
    $entity->payer->target_id = SELF::firstWalletOfUser($mail);
  }
  protected function payeeProcess(TransactionInterface $entity, $mail, $allfields) {
    $entity->payee->target_id = SELF::firstWalletOfUser($mail);
  }

  private function firstWalletOfUser($mail) {
    static $wids;
    if (!isset($wids[$mail])) {
      $uids = \Drupal::entityQuery('user')->condition('mail', $mail)->execute();
      if (!$uids) {
        throw new \Exception('no user with mail '.$mail);
      }
      $user = \Drupal\user\Entity\User::load(reset($uids));

      $wids = \Drupal\mcapi\Mcapi::walletsOf($user);
      if (!$wids) {
        throw new \Exception('no wallet for user '.$user->id());
      }
      $wids[$mail] = reset($wids);
    }
    return $wids[$mail];
  }


}
