<?php

/**
 * @file
 * Contains \Drupal\hamlets\Plugin\DevelGenerate\HamletsUserGenerate.
 * @see https://www.drupal.org/node/2503429 for possible reason why batching doesn't work
 */

namespace Drupal\hamlets\Plugin\DevelGenerate;

use Drupal\devel_generate\Plugin\DevelGenerate\UserDevelGenerate;
use Drupal\user\Entity\User;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a UserDevelGenerate plugin.
 *
 * @DevelGenerate(
 *   id = "hamlets_user",
 *   label = @Translation("Users friendly "),
 *   description = @Translation("Generate 26 users with English names. Optionally delete current users."),
 *   url = "user/friendly",
 *   permission = "administer devel_generate",
 *   settings = {
 *     "kill" = FALSE,
 *     "pass" = ""
 *   }
 * )
 */
class HamletsUserGenerate extends UserDevelGenerate {

  /**
   * The user storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $userStorage;

  /**
   * The date formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $dateFormatter;


  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);
    $form['num']['#value'] = 26;
    $form['num']['#disabled'] = 26;
    unset($form['roles']);
    unset($form['pass']);
    $form['time_range']['#default_value'] = 31536000;
    $form['time_range']['#type'] = 'hidden';
  }

  /**
   * {@inheritdoc}
   */
  protected function generateElements(array $values) {
    $kill = $values['kill'];
    $pass = $values['pass'];
    $age = $values['time_range'];
    $roles = array_filter($values['roles']);

    if ($kill) {
      $uids = $this->userStorage->getQuery()
        ->condition('uid', 1, '>')
        ->execute();
      $users = $this->userStorage->loadMultiple($uids);
      $this->userStorage->delete($users);
    }

    $first = ['Alice', 'Barry', 'Cherry', 'Dante', 'Ebeneezer', 'Fanny', 'Garry', 'Harry', 'Irma', 'Jerry', 'Kerry', 'Larry', 'Murray', 'Nancy', 'Oliver', 'Perry', 'Quentin', 'Ruby', 'Sylvester', 'Terry', 'Ursula', 'Veronica', 'William', 'Xanadu', 'Yuri', 'Zoe'];
    $last = ['Archer', 'Barker', 'Cooper', 'Duke', 'Earl', 'Fisher', 'Gardener', 'Hooper', 'Indignado', 'Joyner', 'Kellogg', 'Leach', 'Mason', 'Nurse', 'Offal', 'Parker', 'Quarkson', 'Rake', 'Smith', 'Turner', 'Undertaker', 'Vicar', 'Waterman', 'X', 'Yardley', 'Zapatero'];
    shuffle($first);
    shuffle($last);

    if (empty($roles)) {
      $roles = [DRUPAL_AUTHENTICATED_RID];
    }
    //@todo inject this
    $accountSwitcher = \Drupal::service('account_switcher');
    //before saving accounts we need to switch to user 1 otherwise the wallet name will be wrongly derived
    $accountSwitcher->switchTo(User::load(1));
    for ($i = 0; $i < 26; $i++) {
      $account = $this->userStorage->create([
        'uid' => NULL,
        'name' => $first[$i],
        'pass' => 'a',
        'mail' => $first[$i] . '@example.com',
        'status' => 1,
        'created' => REQUEST_TIME - mt_rand(0, $age),
        'roles' => array_values($roles)
      ]);

      // Populate all fields with sample values.
      $this->populateFields($account);
      //replace the default content with a sensible name
      $account->firstname->value = $first[$i];
      $account->lastname->value = $last[$i];
      $account->address->country_code = strtoupper(\Drupal::config('system.date')->get('country.default'));
      $account->address->dependent_locality = $neighbourhoods[array_rand($neighbourhoods)];
      $account->save();
    }
    $this->setMessage('26 users created.');

    $accountSwitcher->switchBack();
  }

  function randNeighbourhood() {
    $neighbourhoods = [
      'Apple Green',
      'Black Hills',
      'Cow Common',
      'Ditchwater',
      'Elephantine'
    ];

    return $neighbourhoods[array_rand($neighbourhoods)];
  }

}
