<?php

/**
 * @file
 * Contains \Drupal\hamlets\RewardReferrer.
 *
 */
namespace Drupal\hamlets;

use Drupal\mcapi\Entity\Transaction;
use Drupal\user\Entity\User;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\KeyValueStore\KeyValueFactory;
use Drupal\Core\Routing\RedirectDestination;
use Symfony\Component\DependencyInjection\ContainerInterface;

class RewardReferrer extends FormBase {

  private $keyValue;
  private $user;

  /**
   *
   * @param type $routeMatch
   * @param KeyValueFactory $keyValue
   * @param RedirectDestination $destination
   */
  public function __construct($routeMatch, KeyValueFactory $keyValue, RedirectDestination $destination) {
    //parent::__construct($entity_manager);
    $this->user = User::load($routeMatch->getParameter('user'));
    $this->keyValue = $keyValue->get('hamlets_referrer');
    $this->destination = $destination->get();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      //$container->get('entity.manager'),
      $container->get('current_route_match'),
      $container->get('keyvalue'),
      $container->get('redirect.destination')
    );
  }


  /**
   * {@inheritdoc}
   */
  public function getFormID() {
    return 'hamlets_reward_referrer';
  }


  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $uid = $this->keyValue->get($this->user->id());
    if (!$uid) {
      return ['#markup' => 'No referrals are awaiting payment from this user'];
    }

    $form['intro'] = [
      '#markup' => t(
        'Who did %name mean when noiminating %referrer?',
        [
          '%name' => $this->user->getUsername(),
          '%referrer' => $this->keyValue->get($this->user->id())
        ]
      )
    ];
    $form['referrer'] = [
      '#title' => t('Referrer'),
      '#description' => t('This member will receive a reward.')
    ];
    Self::addReferrerElement($form);
    $form['actions'] = [
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Pay')
      ]
    ];
    return $form;
  }


  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    Self::reward(
      $this->user,
      User::load($form_state->getValue('referrer'))
    );
    $this->keyValue->delete($this->user->id());
  }

  public static function addReferrerElement(&$form) {
    //upgrade the field so user to use autocomplete on trader names
    $form['referrer'] = [
      '#type' => 'entity_autocomplete',
      '#target_type' => 'user',
      '#selection_handler' => 'default:user',
      '#selection_settings' => [
        'include_anonymous' => 0,
        'filter' => [
          'type' => 'role',
          'role' => [RID_TRADER => RID_TRADER]
        ],
        'sort' => [
          'field' => 'name',
          'direction' => 'ASC'
        ]
      ],
      '#placeholder' => t('Name...'),
      '#tags' => FALSE
    ] + $form['referrer'];
    $form['#validate'][] = 'hamlets_referrer_validate';
    $form['actions']['submit']['#submit'][] = 'hamlets_pay_referrer';
  }

  public static function reward($newUser, $referrerUser) {
    //note have no way to determine WHICH of the user's wallets to pay
    $payee_wallet_ids = \Drupal\mcapi\Mcapi::walletsOf($referrerUser);
    $settings = \Drupal::Config('hamlets.settings');
    //assumes one currency only
    $props['worth'] = $settings->get('referral_fee');
    $props['payer'] = $settings->get('referral_src');
    $props['payee'] = reset($payee_wallet_ids)->id();
    $props['type'] = 'auto';
    $props['description'] = t(
      'Reward for referring new member %name',
      ['%name' => $newUser->getUsername()]
    );
    Transaction::create($props)->save();

    drupal_set_message(t(
      '%name was rewarded for referring this member',
      ['%name' => $referrerUser->getUsername()]
    ));
  }

}
