<?php

/**
 * @file
 * Definition of Drupal\mcapi\ViewBuilder\WalletViewBuilder.
 */

namespace Drupal\mcapi\ViewBuilder;

use Drupal\Core\Entity\EntityViewBuilder;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;
use Drupal\Core\Language\LanguageManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Render controller for wallets.
 */
class WalletViewBuilder extends EntityViewBuilder {

  private $localTaskManager;
  private $accessManager;

  /**
   * Constructs a new EntityViewBuilder.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity manager service.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager.
   */
  public function __construct(EntityTypeInterface $entity_type, EntityTypeManagerInterface $entity_type_manager, LanguageManagerInterface $language_manager, $local_task_manager, $access_manager, $entity_manager) {
    //@todo use the parent when the entityTypeManager is applied
    $this->entityTypeId = $entity_type->id();
    $this->entityType = $entity_type;
    $this->entityManager = $entity_manager;
    $this->languageManager = $language_manager;
    //parent::__construct($entity_type, $entity_type_manager, $language_manager);
    $this->localTaskManager = $local_task_manager;
    $this->accessManager = $access_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    return new static(
      $entity_type,
      $container->get('entity_type.manager'),
      $container->get('language_manager'),
      $container->get('plugin.manager.menu.local_task'),
      $container->get('access_manager'),
      $container->get('entity.manager')//deprecated
    );
  }


  /**
   * {@inheritdoc}
   * For multiple nice wallets see theme callback 'mcapi_wallets'
   */
  protected function getBuildDefaults(EntityInterface $entity, $view_mode) {
    $build = parent::getBuildDefaults($entity, $view_mode);
    //add the css
    $build['#attached'] = ['library' => ['mcapi/mcapi.wallets']];
    return $build;
  }

  /**
   * default Wallet entity_label_callback
   *
   * put the Holder entity's name with the wallet name in brackets if there is one
   */
  public static function defaultLabel($wallet) {
    if ($wallet->payways == \Drupal\mcapi\Entity\Wallet::PAYWAY_AUTO) {
      return t('Import/Export');
    }
    $name = $wallet->name->value;
    $holdername = $wallet->getHolder()->label();
    if ($name) {
      return  $holdername .' ('.$name.')';
    }
    else return $holdername;
  }

   /**
   * {@inheritdoc}
   */
  public function buildComponents(array &$build, array $entities, array $displays, $view_mode) {
    parent::buildComponents($build, $entities, $displays, $view_mode);
    $display = $displays['mcapi_wallet'];
    foreach ($entities as $key => $wallet) {
      $extra = mcapi_entity_extra_field_info()['mcapi_wallet']['mcapi_wallet']['display'];
      foreach (['balances', 'balance_bars', 'histories', 'stats'] as $component) {
        if ($info = $display->getComponent($component)) {
          $build[$key][$component] = [
            '#title' => $extra[$component]['label'],
            '#theme' => 'wallet_'.$component,
            '#wallet' => $wallet,
            '#attributes' => ['class' => ['component', $component]],
            '#theme_wrappers' => ['mcapi_wallet_component'],
            '#weight' => $info['weight'],
          ];
        }
      }
      if ($info = $display->getComponent('link_income_expenditure')) {
        $build[$key]['link_income_expenditure'] = [
          '#type' => 'link',
          '#title' => t('Income & Expenditure'),
          '#url' => Url::fromRoute('view.income_expenditure.income_page', ['mcapi_wallet' => $wallet->id()]),
          '#attributes' => ['class' => 'wallet-link'],
        ];
        //views_embed_view('income_expenditure', 'income_embed', $wallet->id());
      }
      if ($info = $display->getComponent('link_transactions')) {
        $build[$key]['link_transactions'] = [
          '#type' => 'link',
          '#title' => t('View transactions'),
          '#url' => Url::fromRoute('view.wallet_transactions.page', ['mcapi_wallet' => $wallet->id()]),
          '#attributes' => ['class' => 'wallet-link'],
        ];
      }
      if ($info = $display->getComponent('canonical_link')) {
        $build[$key]['canonical_link'] = [
          '#type' => 'link',
          '#title' => $this->t('more...'),
          '#url' => Url::fromRoute('entity.mcapi_wallet.canonical', ['mcapi_wallet' => $wallet->id()]),
          '#attributes' => ['class' => 'wallet-link'],
          '#weight' => $info['weight']
        ];
      }
      if ($info = $display->getComponent('holder_link')) {
        $holder = $wallet->getHolder();
        $build[$key]['holder_link'] = [
          '#type' => 'link',
          '#title' => $this->t('Held by %name', ['%name' => $holder->label()]),
          '#url' => $holder->toUrl('canonical'),
          '#attributes' => ['class' => 'wallet-link'],
          '#weight' => $info['weight']
        ];
      }
    }
    //@todo this should probably go elsewhere, and only on non-canonical pages
//    $build['#prefix'] = '<div class="wallets">';
//    $build['#suffix'] = '</div>';
  }
}
