<?php

/**
 * @file
 * Contains \Drupal\realname\Plugin\EntityReferenceSelection\RealnameSelection.
 */

namespace Drupal\realname\Plugin\EntityReferenceSelection;

use Drupal\Component\Utility\Html;
use Drupal\user\Plugin\EntityReferenceSelection\UserSelection;

/**
 * Provides specific access control for the user entity type.
 * this deriver completely broke this handler. No time to sort it out!
 *   deriver = "Drupal\Core\Entity\Plugin\Derivative\DefaultSelectionDeriver"
 *
 * @EntityReferenceSelection(
 *   id = "realname:user",
 *   label = @Translation("User selection"),
 *   entity_types = {"user"},
 *   group = "realname",
 *   weight = 1,
 * )
 */
class RealnameSelection extends UserSelection {


  /**
   * {@inheritdoc}
   */
  public function validateReferenceableEntities(array $ids) {
    $result = [];
    if ($ids) {
      $target_type = $this->configuration['target_type'];
      $entity_type = $this->entityManager->getDefinition($target_type);
      $query = $this->buildQuery();
      //normally an entityquery is only on one table or at least there's no ambiguity
      //but here we need to specify the table alias
      $result = $query
        ->condition('u.uid', $ids, 'IN')
        ->execute()->fetchCol();
    }

    return $result;
  }


  protected function buildEntityQuery($match = NULL, $match_operator = 'CONTAINS') {
    mtrace();
    die('matslats try to divert this to buildQuery');
  }

  /**
   * {@inheritdoc}
   * //replaces buildEntityQuery
   * @todo I don't know why this is returning all users
   *
   */
  protected function buildQuery($match = NULL, $match_operator = 'CONTAINS') {
    //there are very limited options for altering an entityQuery, so at least
    //for now, we're going to build a new query from scratch rather than calling the parent
    //$query = parent::buildEntityQuery($match, $match_operator);
    $query = \Drupal::database()->select('users_field_data', 'u')
      ->fields('u', ['uid'])
      ->condition('u.uid', 0, '>')
      ->addTag('user_access')
      ->addTag('entity_reference')
      // Add the Selection handler for system_query_entity_reference_alter().
      ->addMetaData('entity_reference_selection_handler', $this);
    $query->join('realname', 'r', 'r.uid = u.uid');

    if (!$this->currentUser->hasPermission('administer users')) {
      $query->condition('u.status', 1);
    }

    if (isset($handler_settings['target_bundles']) && is_array($handler_settings['target_bundles'])) {
      $query->condition($entity_type->getKey('bundle'), $handler_settings['target_bundles'], 'IN');
    }
    if (isset($match)) {
      $match.='%';
      $query->condition(db_or()//@deprecated
        ->condition('u.name', $match, 'LIKE')
        ->condition('r.realname', $match, 'LIKE')
      );
    }

    // Add the sort option.
    if (!empty($handler_settings['sort'])) {
      $sort_settings = $handler_settings['sort'];
      if ($sort_settings['field'] != '_none') {
        $query->sort($sort_settings['field'], $sort_settings['direction']);
      }
    }

    // Filter by role.
    $handler_settings = $this->configuration['handler_settings'];
    if (!empty($handler_settings['filter']['role'])) {
      $query->condition('roles', $handler_settings['filter']['role'], 'IN');
    }
    return $query;
  }


  /**
   * {@inheritdoc}
   *
   */
  public function getReferenceableEntities($match = NULL, $match_operator = 'CONTAINS', $limit = 0) {
    $target_type = $this->configuration['target_type'];

    $query = $this->buildQuery($match, $match_operator);
    if ($limit > 0) {
      $query->range(0, $limit);
    }
    $result = $query->execute()->fetchCol();
    //compare the parent::getReferenceableEntities
    //I think empty($result) behaves differently on an entityQuery, which this override is not

    $options = array();
    $entities = entity_load_multiple($target_type, $result);
    foreach ($entities as $entity_id => $entity) {
      $bundle = $entity->bundle();
      $options[$bundle][$entity_id] = Html::escape($entity->label());
    }

    return $options;
  }

}
