<?php

/**
 * @file
 * Contains \Drupal\realname\Form\SettingsForm.
 *
 */
namespace Drupal\realname;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class SettingsForm extends ConfigFormBase {

  private $moduleHandler;

  /**
   * {@inheritdoc}
   */
  public function getFormID() {
    return 'realname_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->configFactory->get('realname.settings');
    
    foreach (\array_keys(\Drupal::token()->getInfo()['tokens']['user']) as $tok) {
      $tokens[] = '[user:'.$tok.']';
    }
    $form['pattern'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Realname pattern'),
      '#description' => \implode(', ', $tokens),
      '#default_value' => $config->get('pattern'),
      '#element_validate' => ['token_element_validate'],
      '#token_types' => ['user'],
      '#min_tokens' => 1,
      '#required' => TRUE,
      '#maxlength' => 256,
      '#weight' => 1
    ];
    $form['login'] = [
      '#title' => $this->t('Login with the realname'),
      '#desciption' => $this->t('Names will be checked for uniqueness'),
      '#type' => 'checkbox',
      '#default_value' => $config->get('login'),
      '#weight' => 5
    ];
    
    return parent::buildForm($form, $form_state);
  }
  
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (strpos($form_state->getValue('realname_pattern'), '[user:name]') !== FALSE) {
      $form_state->setErrorByName(
        'pattern', 
        $this->t('The <em>[user:name]</em> token cannot be used as it will cause recursion.')
      );
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('realname.settings')
      ->set('pattern', $form_state->getValue('pattern'))
      ->set('login', $form_state->getValue('login'))
      ->save();
    
    //clear all the possible caches
    db_truncate('realname')->execute();
    drupal_static_reset('realname_load_multiple');
    \Drupal::entityTypeManager()
      ->getStorage('user')
      ->resetCache();
    parent::submitForm($form, $form_state);
  }

  protected function getEditableConfigNames() {
    return ['realname.settings'];
  }

}
