<?php

/**
 * @file
 * Contains \Drupal\smallads\Plugin\Derivative\SmallAdMenuLink.
 */

namespace Drupal\smallads\Plugin\Derivative;

use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Component\Plugin\Derivative\DeriverBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides menu links definitions to connect to the auto view
 */
class SmallAdMenuLink extends DeriverBase implements ContainerDeriverInterface {

  var $derivatives = [];
  var $smallAdTypeStorage;

  /**
   * {@inheritDoc}
   *
   */
  public function __construct($smallAdTypeStorage) {
    $this->smallAdTypeStorage = $smallAdTypeStorage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('entity.manager')->getStorage('smallad_type')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    //A link to add each type of add in no particular order.
    //Can be moved around by user 1

    foreach ($this->smallAdTypeStorage->loadMultiple() as $id => $type) {
      $this->derivatives["smallad.add.{$id}.link"] = [
        'title' => 'Add '.$type->label(),
        //@todo I don't know how to translate the title
        'title_arguments' => ['@type' => $type->label()],
        'route_name' => 'smallad.add',
        'route_parameters' => ['smallad_type' => $id],
        'provider' => 'smallads',
        'menu_name' => 'account',//@todo find somewhere better to put these
        'weight' => $type->getWeight()
      ];
    }
    /*
    //main menu links to the categories view.
    //under these are tabs, see \Drupal\smallads\Plugin\Derivative\SmallAdTasks
    foreach ($this->termStorage->loadTree('smallad_types') as $type) {
      //assumes bundle names don't clash!
      $this->derivatives['ads.autoviews.'.$type->tid] = [
        'title' => $type->name,//is this translated later?
        'description' => $type->description__value,//is this translated later?
        'parent' => '',
        'route_name' => 'view.ads.page_all.'.$type->tid,//taken from the routesubscriber
        'route_parameters' => ['arg_0' => $type->tid],
        'menu_name' => 'main'
      ]+ $base_plugin_definition;
    }
     *
     */



    //@todo might be nice to have some translated aliases for this
    //path is currently ads/{$tid} whereas '/offers' would be nicer
    return $this->derivatives;
  }
}
