<?php

/**
 * @file
 * Contains \Drupal\smallads\Plugin\Derivative\SmallAdTasks.
 */

namespace Drupal\smallads\Plugin\Derivative;

use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Component\Plugin\Derivative\DeriverBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides local action definitions to create a wallet for all entities of types configured.
 */
class SmallAdTasks extends DeriverBase implements ContainerDeriverInterface {

  var $derivatives = [];
  var $storage = [];

  /**
   * {@inheritDoc}
   *
   */
  public function __construct($smallad_type_storage) {
    $this->storage = $smallad_type_storage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('entity.manager')->getStorage('smallad_type')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    
    $types = $this->storage->loadMultiple();
    $parent_id = 'view.ads_by_category.page_all';
    //this is the default task
    $first_type = array_shift($types);
    $this->derivatives[$parent_id .'.all'] = [
      'title' => $first_type->label(),//how to translate this? title callback?
      'base_route' => $parent_id,
      'route_name' => $parent_id,
      'route_parameters' => ['arg_0' => $first_type->id()],
      'weight' => -1,
    ] + $base_plugin_definition;
    foreach ($types as $id => $type) {
      $this->derivatives[$parent_id .'.'. $id ] = [
        'title' => $type->label(),
        'base_route' => $parent_id,
        'route_name' => $parent_id.'.'.$id,
        'route_parameters' => ['arg_0' => $id],
        //'weight' => $term->weight->value,
      ] + $base_plugin_definition;
    }
    
    //link for the user tabs
    $this->derivatives['user.smallads'] = [
      'title' => 'Small ads',
      'base_route' => $parent_id,
      'route_name' => $parent_id.'.'.$id,
      'route_parameters' => ['user' => $id],
      //'weight' => $term->weight->value,
    ] + $base_plugin_definition;
    
    //print_r($this->derivatives);die();
    return $this->derivatives;
  }
}
