<?php

/**
 * @file
 * Contains \Drupal\cforge\Forms\Settings.
 *
 */
namespace Drupal\cforge\Forms;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class Settings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormID() {
    return 'cforge_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildform($form, $form_state);
    $config = $this->config('cforge.settings');
    $form['mail'] = [
      '#title' => $this->t('Mail'),
      '#type' => 'details',
      'mail_footer' => [
        '#title' => $this->t('Footer'),
        '#description' => $this->t('Appended to all mails sent by the site to members. HTML is allowed.'),
        '#type' => 'textarea',
        '#rows' => 4,
        '#default_value' => $config->get('mail_footer')
      ],
      //the broadcast settings would go here
      '#weight' => 2
    ];

    Self::buildLoginOptions($form);
    $form['name_mode']['#weight'] = 3;

    $form['robots_protect'] = [
      '#title' => t('Conceal from search engines'),
      '#description' => t('Rewrites the robots.txt file'),
      '#type' => 'checkbox',
      '#default_value' => $config->get('robots_protect', 0),
      '#weight' => 4
    ];
    $form['flat_menus'] = [
      '#title' => t('Enforce flat menus'),
      '#description' => t('Keep main menu and secondary menu flat'),
      '#type' => 'checkbox',
      '#default_value' => $config->get('flat_menus', 0),
      '#weight' => 5
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $config = $this->configFactory->getEditable('cforge.settings');
    $config
      ->set('mail_footer', $values['mail_footer'])
      ->set('robots_protect', $values['robots_protect'])
      ->set('flat_menus', $values['flat_menus'])
      ->save();
  }

  function getEditableConfigNames() {
    return ['cforge.settings', 'realname.settings'];
  }

  static function buildLoginOptions(&$form, $weight = 0) {
    $form['names'] = [
      '#title' => t('Names'),
      '#description' => t('Every user has a unique account name, for logging in, and a display names which is comprised of first name plus last name.'),
      '#type' => 'details',
      '#open' => TRUE,
      '#weight' => $weight
    ];
    $form['names']['real_name_login'] = [
      '#title' =>  t('Allow login using real name'),
      '#description' =>  t('Unique real names would be enforced'),
      '#type' => 'checkbox',
      '#default_value' => \Drupal::configFactory()->get('realname.settings')->get('login'),
      '#weight' => 1,
    ];
    $form['names']['account_name_display'] = [
      '#title' =>  t('Display the account name in brackets after the real name'),
      '#type' => 'checkbox',
      '#default_value' => \Drupal::config('cforge.settings')->get('account_name_display'),
      '#weight' => 3
    ];
    $form['names']['name_legacy_mode'] = [
      '#type' => 'value',
      '#value' => FALSE,
      '#weight' => 2
    ];

    $form['#submit'][] = ['\Drupal\cforge\Forms\Settings', 'submitLoginOptions'];
  }

  /**
   * form submit callback, used here but also in HamletsConfigureForm as a setup option
   *
   * @param type $form
   * @param type $form_state
   */
  static function submitLoginOptions($form, $form_state) {

    \Drupal::configFactory()
      ->getEditable('cforge.settings')
      ->set('account_name_display', $form_state->getValue('account_name_display'))
      ->save();
        //realname module settings @todo this should be overridden with a config file
    \Drupal::configFactory()
      ->getEditable('realname.settings')
      ->set('login', $form_state->getValue('real_name_login'))
      ->save();


  }
}
